@@ -1,11 +1,12 @@
 """Entry point for the command line interface"""
 from __future__ import annotations
 
-from argparse import SUPPRESS
+from argparse import SUPPRESS, Action
 
 import simple_parsing
 
-from uetools.commands import commands
+from uetools.commands import commands, find_command
+from uetools.core.conf import BadConfig, select_engine_version
 
 
 # pylint: disable=protected-access
@@ -13,6 +14,23 @@ from uetools.commands import commands
 class HelpFormatter(simple_parsing.SimpleHelpFormatter):
     """Tweak the arrgument usage format to not show too many duplicates"""
 
+    def __init__(self, prog, max_help_position, width=None):
+        super().__init__(prog=prog, max_help_position=max_help_position, width=width)
+        self.command = find_command(prog.split(" ")[-1])
+
+    def _get_help_string(self, action: Action) -> str | None:
+        help = super()._get_help_string(action=action)
+        lines = help.split("\n", maxsplit=1)
+        return lines[0]
+
+    def add_usage(self, usage, actions, groups, prefix=None):
+        if usage is None and self.command:
+            examples = "\n       ".join(self.command.examples())
+
+            usage = examples + "\n\ndescription:\n    " + self.command.help()
+
+        super().add_usage(usage, actions, groups, prefix)
+
     class _Section:
         def __init__(self, formatter, parent, heading=None):
             self.formatter = formatter
@@ -59,18 +77,32 @@ class ArgumentParser(simple_parsing.ArgumentParser):
 
     def _get_formatter(self):
         return HelpFormatter(prog=self.prog, max_help_position=45, width=None)
+        # return BaseArgumentHelpFormatter()
+        # return
 
 
 def parse_args(argv):
     """Setup the argument parser for all supported commands"""
     parser = ArgumentParser()
+    parser.add_argument(
+        "--engine-version",
+        nargs="?",
+        type=str,
+        default=None,
+        help="Engine version to use if you have multiple installed",
+    )
 
     subparsers = parser.add_subparsers(dest="command")
 
     for _, command in commands.items():
         command.arguments(subparsers)
 
-    return parser.parse_args(argv)
+    args = parser.parse_args(argv)
+    if args.engine_version is not None:
+        select_engine_version(args.engine_version)
+        args.engine_version = None
+
+    return args
 
 
 def args(*a):
@@ -82,10 +114,12 @@ def main(argv=None):
     """Entry point for the command line interface"""
     import sys
 
-    parsed_args = parse_args(argv)
+    try:
+        parsed_args = parse_args(argv)
+    except BadConfig:
+        sys.exit(-1)
 
     cmd_name = parsed_args.command
-
     command = commands.get(cmd_name)
 
     if command is None:
